aboutsummaryrefslogtreecommitdiff
path: root/tests/test-chime-declined-events-predicate.el
diff options
context:
space:
mode:
Diffstat (limited to 'tests/test-chime-declined-events-predicate.el')
-rw-r--r--tests/test-chime-declined-events-predicate.el12
1 files changed, 7 insertions, 5 deletions
diff --git a/tests/test-chime-declined-events-predicate.el b/tests/test-chime-declined-events-predicate.el
index ca25faa..5f8c4b8 100644
--- a/tests/test-chime-declined-events-predicate.el
+++ b/tests/test-chime-declined-events-predicate.el
@@ -144,13 +144,15 @@ than treating it as declined."
(let ((marker (point-marker)))
(should-not (chime-declined-events-predicate marker)))))
-;;;; Integration with the default predicate-blacklist
+;;;; Integration with the default exclude filters
-(ert-deftest test-chime-declined-events-predicate-on-default-blacklist ()
- "Normal: the predicate ships in the default `chime-predicate-blacklist'
-so out-of-the-box installs hide declined events without extra config."
+(ert-deftest test-chime-declined-events-predicate-on-default-exclude-filters ()
+ "Normal: the predicate ships in the default `chime-exclude-filters'
+under the predicates key, so out-of-the-box installs hide declined
+events without extra config."
(should (memq 'chime-declined-events-predicate
- (default-value 'chime-predicate-blacklist))))
+ (alist-get 'predicates
+ (default-value 'chime-exclude-filters)))))
(provide 'test-chime-declined-events-predicate)
;;; test-chime-declined-events-predicate.el ends here